@@ -9,33 +9,42 @@ import sys
 import warnings
 from copy import deepcopy
 from glob import glob
+from typing import List
 from urllib.error import HTTPError
 from urllib.request import urlretrieve
 
 import click
 import pandas as pd
-import stanza
 import torch
-from tqdm import tqdm
-from transformers import MarianMTModel, MarianTokenizer
+from tqdm import tqdm  # type: ignore
+from transformers import MarianMTModel, MarianTokenizer  # type: ignore
+
+import stanza  # type: ignore
 
 logger = logging.getLogger(__name__)
 
-FEATURE_TEXT = 'text_raw'
-FEATURE_STANZA = 'stanza'
-FEATURE_CONSTITUENTS = 'constituencies'
-LANGUAGE_COLUMN = 'language'
-DATASET_CSV = 'dataset.csv'
-HF_URL = 'https://s3.amazonaws.com/models.huggingface.co/bert/Helsinki-NLP'
-FILES = ['config.json', 'pytorch_model.bin', 'source.spm',
-         'target.spm', 'tokenizer_config.json', 'vocab.json']
-MODEL_DIR = 'translation_data'
+FEATURE_TEXT = "text_raw"
+FEATURE_STANZA = "stanza"
+FEATURE_CONSTITUENTS = "constituencies"
+LANGUAGE_COLUMN = "language"
+DATASET_CSV = "dataset.csv"
+HF_URL = "https://s3.amazonaws.com/models.huggingface.co/bert/Helsinki-NLP"
+FILES = [
+    "config.json",
+    "pytorch_model.bin",
+    "source.spm",
+    "target.spm",
+    "tokenizer_config.json",
+    "vocab.json",
+]
+MODEL_DIR = "translation_data"
 
 
-@click.command(help='transforms corpora created with the reddit script into '
-                    'the common dataframe format.')
-@click.argument('input_directory')
-def reddit_to_common(input_directory):
+@click.command(
+    help="transforms corpora created with the reddit script to the dataframe format."
+)
+@click.argument("input_directory")
+def reddit_to_common(input_directory: str) -> None:
     """
     Transform corpora created with reddit scripts into dataframe format.
 
@@ -57,7 +66,7 @@ def reddit_to_common(input_directory):
     if not os.path.isdir(text_directory):
         os.makedirs(text_directory)
 
-    old_directory = os.path.join(input_directory, 'old')
+    old_directory = os.path.join(input_directory, "old")
     if not os.path.isdir(old_directory):
         os.makedirs(old_directory)
 
@@ -68,34 +77,33 @@ def reddit_to_common(input_directory):
 
         # don't process these "authors" that might be existing from previous
         # calls to this script:
-        if author in [os.path.basename(text_directory),
-                      os.path.basename(meta_file)]:
+        if author in [os.path.basename(text_directory), os.path.basename(meta_file)]:
             continue
 
         author_dir = os.path.join(input_directory, author)
         if not os.path.isdir(author_dir):
-            logger.warning('not an author directory: %s', author_dir)
+            logger.warning("not an author directory: %s", author_dir)
             continue
         languages = os.listdir(author_dir)
         for language in languages:
             language_dir = os.path.join(author_dir, language)
             if not os.path.isdir(language_dir):
-                logger.warning('not a language directory: %s', language_dir)
+                logger.warning("not a language directory: %s", language_dir)
                 continue
-            json_files = glob(language_dir + '/*.json')
+            json_files = glob(language_dir + "/*.json")
             for json_file in json_files:
                 name_ext = os.path.basename(json_file)
                 name = os.path.splitext(name_ext)[0]
-                text_name = f'{author}_{language}_{name}.txt'
+                text_name = f"{author}_{language}_{name}.txt"
                 text_file = os.path.join(FEATURE_TEXT, text_name)
                 full_text_file = os.path.join(input_directory, text_file)
-                with open(json_file) as i_f, open(full_text_file, 'w') as o_f:
+                with open(json_file) as i_f, open(full_text_file, "w") as o_f:
                     js = json.load(i_f)
-                    o_f.write(js['body_clean'])
-                    del js['body']
-                    del js['body_clean']
+                    o_f.write(js["body_clean"])
+                    del js["body"]
+                    del js["body_clean"]
                     js[FEATURE_TEXT] = text_file
-                    js['group_field'] = language  # important for deepl_...
+                    js["group_field"] = language  # important for deepl_...
                     records.append(js)
 
         # move old author dir
@@ -105,14 +113,19 @@ def reddit_to_common(input_directory):
     df.to_csv(meta_file, index=False)
 
 
-@click.command(help='Reads dataset.csv + column name to produce stanza dir')
-@click.argument('input-directory')
-@click.option('-t', '--text-column-name', default=FEATURE_TEXT)
-@click.option('-l', '--language-column-name', default=LANGUAGE_COLUMN)
-@click.option('-o', '--overwrite', default=False)
-@click.option('-out', '--output-column-name', default=FEATURE_STANZA)
-def parse_dependency(input_directory, text_column_name, language_column_name,
-                     overwrite, output_column_name):
+@click.command(help="Reads dataset.csv + column name to produce stanza dir")
+@click.argument("input-directory")
+@click.option("-t", "--text-column-name", default=FEATURE_TEXT)
+@click.option("-l", "--language-column-name", default=LANGUAGE_COLUMN)
+@click.option("-o", "--overwrite", default=False)
+@click.option("-out", "--output-column-name", default=FEATURE_STANZA)
+def parse_dependency(
+    input_directory: str,
+    text_column_name: str,
+    language_column_name: str,
+    overwrite: bool,
+    output_column_name: str,
+) -> None:
     """
     Parse text files using the stanza parser.
 
@@ -132,7 +145,7 @@ def parse_dependency(input_directory, text_column_name, language_column_name,
     Returns: Nothing, this is a cli script.
 
     """
-    warnings.simplefilter('ignore')  # stanza is very 'loud'.
+    warnings.simplefilter("ignore")  # stanza is very 'loud'.
     main_dataset_file = os.path.join(input_directory, DATASET_CSV)
     df = pd.read_csv(main_dataset_file)
 
@@ -143,37 +156,34 @@ def parse_dependency(input_directory, text_column_name, language_column_name,
 
     df[output_column_name] = [
         os.path.join(
-            output_column_name,
-            os.path.splitext(os.path.basename(f))[0] + '.pckl'
+            output_column_name, os.path.splitext(os.path.basename(f))[0] + ".pckl"
         )
         for f in df[text_column_name]
     ]
 
-    def should_write(f):
+    def should_write(f: str) -> bool:
         if overwrite:
             return True
         if os.path.isfile(f):
             return os.path.getsize(f) == 0
-        return False
+        else:
+            return True
 
     tuples = [
         (in_file, out_file, language)
-        for (in_file, out_file, language)
-        in zip(
-            df[text_column_name],
-            df[output_column_name],
-            df[language_column_name]
+        for (in_file, out_file, language) in zip(
+            df[text_column_name], df[output_column_name], df[language_column_name]
         )
         if should_write(os.path.join(input_directory, out_file))
     ]
     if not tuples:
-        logger.warning('no files remaining, skipping calculation')
+        logger.warning("no files remaining, skipping calculation")
         return
 
     parsers = {}
     for in_file, out_file, language in tqdm(tuples):
-        if language.endswith('_to_en'):
-            language = 'en'
+        if language.endswith("_to_en"):
+            language = "en"
         if language not in parsers:
             parsers[language] = stanza.Pipeline(lang=language, use_gpu=False)
         parser = parsers[language]
@@ -184,26 +194,30 @@ def parse_dependency(input_directory, text_column_name, language_column_name,
             try:
                 parsed = parser(content)
             except RuntimeError as e:
-                logger.error('error on parsing', full_path)
+                logger.error("error on parsing", full_path)
                 logger.error(content)
                 raise e
-            with open(os.path.join(input_directory, out_file), 'wb') as out_fh:
+            with open(os.path.join(input_directory, out_file), "wb") as out_fh:
                 pickle.dump(parsed, out_fh)
-    logger.info('writing %s', main_dataset_file)
+    logger.info("writing %s", main_dataset_file)
     df.to_csv(main_dataset_file, index=False)
 
 
-@click.command(help='reads dataset.csv, produces constituencies directory')
-@click.argument('input-directory')
-@click.option('-t', '--text-column-name', default=FEATURE_TEXT)
-@click.option('-l', '--language-column-name', default=LANGUAGE_COLUMN)
-def parse_constituency(input_directory, text_column_name,
-                       language_column_name):
+@click.command(help="reads dataset.csv, produces constituencies directory")
+@click.argument("input-directory")
+@click.option("-t", "--text-column-name", default=FEATURE_TEXT)
+@click.option("-l", "--language-column-name", default=LANGUAGE_COLUMN)
+def parse_constituency(
+        input_directory: str,
+        text_column_name: str,
+        language_column_name: str
+) -> None:
     """
     Ignore this method for the time being.
 
     This is no longer working unless the common file transformers are replaced.
     """
+    print(input_directory, text_column_name, language_column_name)
     pass
     # meta = os.path.join(input_directory, DATASET_CSV)
     #
@@ -252,8 +266,13 @@ def parse_constituency(input_directory, text_column_name,
 class Translator:
     """Simple translator wrapper for Hugging Face models."""
 
-    def __init__(self, source_language, target_language,
-                 model_dir='translation_models', force_download=False):
+    def __init__(
+        self,
+        source_language: str,
+        target_language: str,
+        model_dir: str = "translation_models",
+        force_download: bool = False,
+    ):
         """
         Initialize the translator.
 
@@ -268,21 +287,21 @@ class Translator:
         self.model_dir = model_dir
         self.force_download = force_download
 
-        self.model_name = (f'opus-mt-{self.source_language}-'
-                           f'{self.target_language}')
+        self.model_name = f"opus-mt-{self.source_language}-" f"{self.target_language}"
         self.model_dir = os.path.join(self.model_dir, self.model_name)
 
-        if not os.path.isdir(self.model_dir or self.force_download):
+        if not os.path.isdir(self.model_dir) or self.force_download:
             self._download_language_model()
 
-        self.device = 'cuda' if torch.cuda.is_available() else 'cpu'
-        logger.info('running on device: %s', self.device)
+        self.device = "cuda" if torch.cuda.is_available() else "cpu"
+        logger.info("running on device: %s", self.device)
 
         self.model = MarianMTModel.from_pretrained(self.model_dir).to(
-            torch.device(self.device))
+            torch.device(self.device)
+        )
         self.tokenizer = MarianTokenizer.from_pretrained(self.model_dir)
 
-    def _download_language_model(self):
+    def _download_language_model(self) -> None:
         if os.path.isdir(self.model_dir):
             shutil.rmtree(self.model_dir)
         os.makedirs(self.model_dir)
@@ -290,14 +309,17 @@ class Translator:
             file_url = os.path.join(HF_URL, self.model_name, f)
             file_path = os.path.join(self.model_dir, f)
             try:
-                logger.info('downloading %s', file_url)
+                logger.info("downloading %s", file_url)
                 urlretrieve(file_url, file_path)
             except HTTPError as e:
-                logger.error('Error retrieving model from url.'
-                             'Please confirm model exists: %s', e)
+                logger.error(
+                    "Error retrieving model from url."
+                    "Please confirm model exists: %s",
+                    e,
+                )
                 sys.exit(1)
 
-    def translate(self, sentences):
+    def translate(self, sentences: List[str]) -> List[str]:
         """
         Translate sentences for source to target language.
 
@@ -310,19 +332,23 @@ class Translator:
         """
         result = []
         for sentence in tqdm(sentences, leave=False):
-            batch = self.tokenizer.prepare_seq2seq_batch(src_texts=[sentence],
-                                                         return_tensors='pt')
+            batch = self.tokenizer.prepare_seq2seq_batch(
+                src_texts=[sentence], return_tensors="pt"
+            )
             translated = self.model.generate(**batch.to(self.device))
-            result += self.tokenizer.batch_decode(translated,
-                                                  skip_special_tokens=True)
+            result += self.tokenizer.batch_decode(translated, skip_special_tokens=True)
         return result
 
 
-@click.command(help='translates data')
-@click.argument('input-dir')
-@click.argument('source')
-@click.argument('target')
-def translate(input_dir, source, target):
+@click.command(help="translates data")
+@click.argument("input-dir")
+@click.argument("source")
+@click.argument("target")
+def translate(
+        input_dir: str,
+        source: str,
+        target: str,
+) -> None:
     """
     Translate common datafrarme corpora.
 
@@ -337,26 +363,26 @@ def translate(input_dir, source, target):
     Returns: Nothing, this is a CLI script.
 
     """
-    key = f'marianmt_{source}_to_{target}'
-    df = pd.read_csv(os.path.join(input_dir, 'dataset.csv'))
-    df = df.drop(columns=[c for c in df.columns if c.startswith('Unnamed: 0')])
-    sub_df = df[df['language'] == source]
+    key = f"marianmt_{source}_to_{target}"
+    df = pd.read_csv(os.path.join(input_dir, "dataset.csv"))
+    df = df.drop(columns=[c for c in df.columns if c.startswith("Unnamed: 0")])
+    sub_df = df[df["language"] == source]
 
-    logger.info('loading translation model')
+    logger.info("loading translation model")
     translator = Translator(source, target)
 
     new_rows = []
 
     for index, row in tqdm(sub_df.iterrows(), total=sub_df.shape[0]):
         new_row = deepcopy(row)
-        old_path = os.path.join(input_dir, row['stanza'])
+        old_path = os.path.join(input_dir, row["stanza"])
         old_name = os.path.splitext(os.path.basename(old_path))[0]
-        new_name = old_name + '__' + key
-        new_path_part = os.path.join('text_raw', new_name + '.txt')
+        new_name = old_name + "__" + key
+        new_path_part = os.path.join("text_raw", new_name + ".txt")
         new_path = os.path.join(input_dir, new_path_part)
-        new_row['text_raw'] = new_path_part
-        new_row['stanza'] = None
-        new_row['language'] = key
+        new_row["text_raw"] = new_path_part
+        new_row["stanza"] = None
+        new_row["language"] = key
 
         new_dir = os.path.dirname(new_path)
         if not os.path.isdir(new_dir):
@@ -370,14 +396,14 @@ def translate(input_dir, source, target):
         if os.path.isfile(new_path):
             continue
 
-        with open(old_path, 'rb') as i_f, open(new_path, 'w') as o_f:
+        with open(old_path, "rb") as i_f, open(new_path, "w") as o_f:
             document = pickle.load(i_f)
             sentences = [sentence.text for sentence in document.sentences]
             translations = translator.translate(sentences)
-            o_f.write('\n'.join(translations))
+            o_f.write("\n".join(translations))
 
         new_rows.append(new_row)
 
     df2 = pd.DataFrame.from_records(new_rows)
     df3 = pd.concat([df, df2])
-    df3.to_csv(os.path.join(input_dir, 'dataset.csv'), index=False)
+    df3.to_csv(os.path.join(input_dir, "dataset.csv"), index=False)
